isb-firm - Framework for Inference of Regulation by miRNAs
==========================================================

Description
-----------

This package provides the FIRM pipeline as a set of command line
tools.

For more information see http://github.com/baliga-lab/firm2
